@@ -17,6 +17,8 @@ from .attribution import Attribution
 from .brand_metrics import BrandMetrics
 from .advertising_test_account import AdvertisingTestAccount
 from .reports import Reports
+from .validation_configurations import ValidationConfigurations
+from .recommendations import Recommendations
 
 __all__ = [
     "sp",
@@ -41,4 +43,6 @@ __all__ = [
     "BrandMetrics",
     "AdvertisingTestAccount",
     "Reports",
+    "ValidationConfigurations",
+    "Recommendations",
 ]
